summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/accountselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/ui/accountselector.h')
-rw-r--r--kopete/libkopete/ui/accountselector.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/ui/accountselector.h b/kopete/libkopete/ui/accountselector.h
index bdb4c888..2ad22a53 100644
--- a/kopete/libkopete/ui/accountselector.h
+++ b/kopete/libkopete/ui/accountselector.h
@@ -37,19 +37,19 @@ Q_OBJECT
/**
* Constructor.
*
* The parameters @p tqparent and @p name are handled by
* KListView.
*/
- AccountSelector(TQWidget *tqparent=0, const char *name=0);
+ AccountSelector(TQWidget *parent=0, const char *name=0);
/**
* Constructor for a list of accounts for one protocol only
*
* The parameters @p tqparent and @p name are handled by
* KListView. @p proto defines the protocol whose accounts are
* shown in the list
*/
- AccountSelector(Kopete::Protocol *proto, TQWidget *tqparent=0, const char *name=0);
+ AccountSelector(Kopete::Protocol *proto, TQWidget *parent=0, const char *name=0);
/**
* Destructor.
@@ -37,19 +37,19 @@ Q_OBJECT
* Constructor.
*
- * The parameters @p tqparent and @p name are handled by
+ * The parameters @p parent and @p name are handled by
* KListView.
*/
@@ -37,19 +37,19 @@ Q_OBJECT
* Constructor for a list of accounts for one protocol only
*
- * The parameters @p tqparent and @p name are handled by
+ * The parameters @p parent and @p name are handled by
* KListView. @p proto defines the protocol whose accounts are
* shown in the list